%global majorversion 2
%global minorversion 12
%global patchversion 0
%global majorminorversion %{majorversion}.%{minorversion}
%global nsversion %{majorversion}.0

%global libmodulemd_version %{majorminorversion}%{?patchversion:.%{patchversion}}

%global libname %mklibname modulemd %{majorversion}
%global devname %mklibname modulemd -d
%global girname %mklibname modulemd-gir %{nsversion}

# The tests seem to stall out and cause the build to fail
# on armv7hl and aarch64, so we're going to disable it there
# for now.
%ifnarch %{arm} aarch64
%bcond_without check
%endif

Name:           libmodulemd
Version:        %{libmodulemd_version}
Release:        %mkrel 1
Summary:        Module metadata manipulation library
Group:          System/Packaging
License:        MIT
URL:            https://github.com/fedora-modularity/libmodulemd
Source0:        https://github.com/fedora-modularity/libmodulemd/releases/download/%{name}-%{version}/modulemd-%{libmodulemd_version}.tar.xz

BuildRequires:  meson >= 0.47.0
BuildRequires:  gcc
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(yaml-0.1)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  python3dist(pygobject)
BuildRequires:  rpm-devel
BuildRequires:  file-devel

%description
C Library for manipulating module metadata files.


%package -n modulemd-validator
Summary:        Tool for validating modulemd data
Group:          System/Packaging
Requires:       %{libname}%{?_isa} = %{libmodulemd_version}-%{release}
# modulemd-v1 is gone
Obsoletes:      modulemd-validator-v1 < 1.8.16-3

%description -n modulemd-validator
The modulemd-validator tool provides the facility for verifying
constructed modulemd data is correct and usable.

%package -n python3-%{name}
Summary:        Python 3 bindings for %{name}
Group:          Development/Python
Requires:       %{girname}%{?_isa} = %{libmodulemd_version}-%{release}
Requires:       python3dist(pygobject)
Requires:       python3dist(six)

%description -n python3-%{name}
This package provides the Python 3 bindings for %{name}.

%package -n %{libname}
Summary:        Main library for %{name}
Group:          System/Libraries
# modulemd-v1 is gone
Obsoletes:      %{mklibname modulemd 1} < 1.8.16-3

%description -n %{libname}
This package provides the main library for applications
that use %{name}.

%package -n %{girname}
Summary:        GObject Introspection interface description for %{name}
Group:          System/Libraries
Requires:       %{libname}%{?_isa} = %{libmodulemd_version}-%{release}
# modulemd-v1 is gone
Obsoletes:      %{mklibname modulemd-gir 1.0} < 1.8.16-3

%description -n %{girname}
This package provides the GObject Introspection typelib interface
for applications to use %{name}.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/C
Provides:       %{name}-devel = %{libmodulemd_version}-%{release}
Provides:       %{name}-devel%{?_isa} = %{libmodulemd_version}-%{release}
Provides:       modulemd-devel = %{libmodulemd_version}-%{release}
Provides:       modulemd-devel%{?_isa} = %{libmodulemd_version}-%{release}
Requires:       %{libname}%{?_isa} = %{libmodulemd_version}-%{release}
Requires:       %{girname}%{?_isa} = %{libmodulemd_version}-%{release}
# modulemd-v1 is gone
Obsoletes:      %{mklibname modulemd 1 -d} < 1.8.16-3

%description -n %{devname}
This package provides files for developing applications to use %{name}.

%prep
%autosetup -p1 -n modulemd-%{libmodulemd_version}

%build
%meson -Ddeveloper_build=false -Dwith_py3_overrides=true -Dwith_py2_overrides=false

%meson_build

%if %{with check}
%check
export LC_CTYPE=C.UTF-8
%meson_test
%endif

%install
%meson_install

%files -n modulemd-validator
%license COPYING
%doc README.md
%{_bindir}/modulemd-validator
%{_mandir}/man1/modulemd-validator.1*

%files -n python3-%{name}
%{python3_sitearch}/gi/overrides/Modulemd.py
%{python3_sitearch}/gi/overrides/__pycache__/Modulemd.*

%files -n %{libname}
%license COPYING
%doc README.md
%{_libdir}/%{name}.so.%{majorversion}{,.*}

%files -n %{girname}
%{_libdir}/girepository-1.0/Modulemd-%{nsversion}.typelib

%files -n %{devname}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/modulemd-%{nsversion}.pc
%{_includedir}/modulemd-%{nsversion}/
%{_datadir}/gir-1.0/Modulemd-%{nsversion}.gir
%{_datadir}/gtk-doc/html/modulemd-%{nsversion}/


%changelog
* Mon Jan 18 2021 luigiwalser <luigiwalser> 2.12.0-1.mga8
+ Revision: 1672362
- 2.12.0

* Wed Dec 30 2020 luigiwalser <luigiwalser> 2.11.1-1.mga8
+ Revision: 1665459
- 2.11.1
- remove upstreamed patch

* Wed Dec 02 2020 luigiwalser <luigiwalser> 2.10.0-1.mga8
+ Revision: 1651752
- 2.10.0
- add 32-bit fix from fedora
- fix source URL

* Tue Jul 07 2020 ngompa <ngompa> 2.9.4-1.mga8
+ Revision: 1602719
- Update to 2.9.4

* Fri Feb 28 2020 ngompa <ngompa> 2.9.1-1.mga8
+ Revision: 1551702
- Update to 2.9.1
- Obsolete modulemd-v1 packages

* Wed Feb 19 2020 umeabot <umeabot> 2.8.3-2.mga8
+ Revision: 1543444
- Mageia 8 Mass Rebuild

* Sun Jan 19 2020 ngompa <ngompa> 2.8.3-1.mga8
+ Revision: 1481568
- Update to 2.8.3

* Sun Dec 08 2019 ngompa <ngompa> 2.8.2-1.mga8
+ Revision: 1465097
- Update to 2.8.2
- libmodulemd1 has been split out into its own tarball/source package

* Sat Sep 21 2019 daviddavid <daviddavid> 2.5.0-2.mga8
+ Revision: 1444476
- rebuild for python3.8

* Tue May 28 2019 ngompa <ngompa> 2.5.0-1.mga7
+ Revision: 1399317
- Update to 2.5.0 (v2) and 1.8.11 (v1)

* Sun May 12 2019 ngompa <ngompa> 2.3.1-1.mga7
+ Revision: 1397460
- Update to 2.3.1 (v2) and 1.8.8 (v1)

* Sun Apr 28 2019 ngompa <ngompa> 2.3.0-2.mga7
+ Revision: 1395806
- Add missing dependency on six module for Python 3 bindings subpackage

* Tue Apr 23 2019 ngompa <ngompa> 2.3.0-1.mga7
+ Revision: 1394895
- Update to 2.3.0 (v2) and 1.8.7 (v1)

* Thu Apr 18 2019 umeabot <umeabot> 2.2.2-2.mga7
+ Revision: 1392788
- Rebuild with meson 0.50.1

* Mon Apr 01 2019 ngompa <ngompa> 2.2.2-1.mga7
+ Revision: 1384398
- Update to 2.2.2 (v2) and 1.8.5 (v1)
- Backport fix to prevent pulling in Python 2 as a dependency

* Sun Feb 03 2019 ngompa <ngompa> 2.1.0-1.mga7
+ Revision: 1362867
- Rebase to libmodulemd 2.1.0 and 1.8.2

* Sun Oct 28 2018 ngompa <ngompa> 1.7.0-2.mga7
+ Revision: 1326332
- Disable running tests during package build on 32-bit ARM

* Sun Oct 28 2018 ngompa <ngompa> 1.7.0-1.mga7
+ Revision: 1326325
- Update to 1.7.0

* Tue Oct 16 2018 ngompa <ngompa> 1.6.4-1.mga7
+ Revision: 1320715
- Update to 1.6.4 and drop merged patches

* Sat Sep 15 2018 ngompa <ngompa> 1.6.3-1.mga7
+ Revision: 1259035
- Update to 1.6.3
- Sync patches from Fedora

* Sat Aug 04 2018 ngompa <ngompa> 1.6.1-1.mga7
+ Revision: 1247247
- Update to 1.6.1

* Sat Jun 30 2018 ngompa <ngompa> 1.5.2-3.mga7
+ Revision: 1240888
- Add compatibility Provides

* Sat Jun 30 2018 ngompa <ngompa> 1.5.2-2.mga7
+ Revision: 1240883
- Adapt for Mageia
- imported package libmodulemd

